==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/vco50SqlHandle.cpp <==
/*!***************************************************************************

  module      : vco50SqlHandle.cpp

  -------------------------------------------------------------------------

  responsible : FerdiF

  special area: C++ SQL Class   
  description : Implementation of SqlHandle 
				
  
  last changed: 2000-03-08  11:22
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

#ifndef GCO50SQLHANDLE_H
#include "gco50SqlHandle.h"
#endif
#ifndef GCO501SQL_H
#include "gco501SQL.h"
#endif
#ifndef GCO51CSQLSESSIONCONTEXT_H
#include "gco51CSqlSessionContext.h"
#endif
#include "hsp81.h"

#if !defined (EXT_CLIENT_SQL) /* PTS 1109256 */
#if defined(QUICK) || defined(SLOW)
externC teo00_Longint
sqlk_rangeviolation (               // ALLIN
                     teo00_Longint     val,
                     teo00_Longint     minVal,
                     teo00_Longint     maxVal,
                     int               lineno,
                     const char       *fileName)
{ int x=0; x=1/10*x; return -1; };

/*----------------------------------------*/

externC void
sqlk_assert (                      // ALLIN
             int            kind,
             int            lineno,
             const char    *filename,
             const char    *condition)
{ int x=0; x=x/10*0; };

#endif
#endif

/*----------------------------------------------------------------------*/
/* Implementation of default error handler                              */
/*----------------------------------------------------------------------*/

void
#if defined(WIN32)
__cdecl
#endif
sqlDefaultHandler ( SqlHandle* p_sqlhandle )
{
  if ( p_sqlhandle->sqlCode() != 100 ) {
    if ( p_sqlhandle->sqlIsUnicodeErrMsg() )
      throw DbpError(DbpError::DB_ERROR_UNICODE,
      p_sqlhandle->sqlCode(),
      p_sqlhandle->sqlUnicodeErrorMsg());
    else
      throw DbpError(DbpError::DB_ERROR,
      p_sqlhandle->sqlCode(),
      p_sqlhandle->sqlErrorMsg());
  }
}

/*----------------------------------------------------------------------*/
/* Implementation of class SqlHandle                                    */
/*----------------------------------------------------------------------*/

SqlHandle::SqlHandle () {
  m_session         = NULL;
  m_session_context = NULL;
  sqlSetHandler(&sqlDefaultHandler);
  m_session_context = new co51CSqlSessionContext(*this);
};

/*----------------------------------------------------------------------*/

SqlHandle::~SqlHandle () {
  m_session_context->deleteSelf();
};

/*----------------------------------------------------------------------*/

SQL SqlHandle::sql(const char* stmt) {
  return SQL(this, stmt);
};

/*----------------------------------------------------------------------*/

SQL SqlHandle::sql(const DbpTypeUnicode* stmt) {
  return SQL(this, stmt);
};

/*----------------------------------------------------------------------*/

short SqlHandle::sqlCode () const {
  if (m_session_context)
    return m_session_context->sqlCode ();
  else 
    return e_unknown_error;
};

/*----------------------------------------------------------------------*/

const char* SqlHandle::sqlErrorMsg() const {
  if (m_session_context) 
    return m_session_context->sqlErrorMsg ();
  else
    return NULL;
};

/*----------------------------------------------------------------------*/

const DbpTypeUnicode* SqlHandle::sqlUnicodeErrorMsg() const {
  if (m_session_context) 
    return m_session_context->sqlUnicodeErrorMsg ();
  else
    return NULL;
};

/*----------------------------------------------------------------------*/
#if !defined (EXT_CLIENT_SQL)
void SqlHandle::sqlExceptionHandler(DbpError& e) {
  if ( *m_session )
  switch (e.m_errorKind) {
  case DbpError::DB_ERROR :
  case DbpError::RTE_ERROR :
  case DbpError::USER_DEFINED :
    {
      sqlRaiseError ((short) e.m_errorNo, &e.m_errorText[0]);
      break;
    }
  case DbpError::DB_ERROR_UNICODE :
  case DbpError::USER_DEFINED_UNICODE :
    {
      sqlRaiseError ((short) e.m_errorNo, REINTERPRET_CAST(DbpTypeUnicode*,&e.m_errorText[0]));
      break;
    }
  case DbpError::HRESULT_ERROR :
    {
      (*m_session)->HResultError (e.m_errorNo);
      break;
    }
  default :
    dbpOpError ("Invalid DbpError, kind = %d, errno = %d", e.m_errorKind, e.m_errorNo);
    throw;
  }
}
#endif

/*----------------------------------------------------------------------*/

long SqlHandle::sqlErrorPos () const {
  if (m_session_context) 
    return m_session_context->sqlErrorPos ();
  else 
    return -1;
}

/*----------------------------------------------------------------------*/

void  SqlHandle::sqlInitSession (IUnknown** s) {
  m_session = (IliveCacheSink**) s;
};

/*----------------------------------------------------------------------*/

int  SqlHandle::sqlIsUnicodeErrMsg () const {
  return m_session_context->sqlIsUnicodeErrMsg();
};

/*----------------------------------------------------------------------*/

long SqlHandle::sqlResultCount () const {
  if (m_session_context) 
    return m_session_context->sqlResultCount ();
  else
    return -1;
}

/*----------------------------------------------------------------------*/

void SqlHandle::sqlRaiseError (short msgno, const char* errmsg) {
#if defined(EXT_CLIENT_SQL)
  throw DbpError(msgno,errmsg);
#else
  if ( *m_session )
    (*m_session)->SetError (msgno, strlen (errmsg), (unsigned char*) errmsg,
    csp_ascii );
#endif
};

/*----------------------------------------------------------------------*/

void SqlHandle::sqlRaiseError (short msgno, const DbpTypeUnicode* errmsg) {
#if defined(EXT_CLIENT_SQL)
  throw DbpError(msgno,errmsg);
#else
  if ( *m_session ) {
    tsp81_UCS2Char    UCS2Blank;
    int               UCS2Swap;
    UCS2Blank.s = 32;
    UCS2Swap    =  (UCS2Blank.c[0] ? 1 : 0 ); 
    
    int len = sp81UCS2strlen((tsp81_UCS2Char*)errmsg);
    
    if ( UCS2Swap ) {
      DbpTypeUnicode    l_errmsg[256];

      if ( len > 256 ) len = 256;
      sp81UCS2strncpy( REINTERPRET_CAST(tsp81_UCS2Char*,l_errmsg), 
        REINTERPRET_CAST(const tsp81_UCS2Char*,errmsg), 256 );
      for ( int i=0; i<len; i++) {
        l_errmsg[i] = l_errmsg[i] << 8;
      }
      (*m_session)->SetError (msgno, len*2, (unsigned char*) &l_errmsg[0], csp_unicode);
    }
    else
      (*m_session)->SetError (msgno, len*2, (unsigned char*) errmsg, csp_unicode);
  }
#endif
};

/*----------------------------------------------------------------------*/

void SqlHandle::sqlResetSession( ) {
//  m_sqlmsg->m_snd_packet_size = 0;
};

/*----------------------------------------------------------------------*/

void SqlHandle::sqlSetMode(const SqlOpt::SqlSessionMode mode) {
  if (m_session_context) 
    m_session_context->sqlSetMode(mode);
}

/*----------------------------------------------------------------------*/

const char* SqlHandle::sqlState () const {
  if (m_session_context)
    return m_session_context->sqlState();
  else
    return NULL;
};

/*----------------------------------------------------------------------*/

char SqlHandle::sqlWarning (int i) const {
  if (m_session_context)
    return m_session_context->sqlWarning(i);
  else
    return ' ';
};

/*----------------------------------------------------------------------*/

#if !defined (EXT_CLIENT_SQL)

HRESULT SqlHandle::AdviseSqlSession () {
  if ( m_session )
    dbpAdviseLcSink(*m_session);
  return S_OK;
}

/*----------------------------------------------------------------------*/

HRESULT SqlHandle::UnAdviseSqlSession () {
  dbpAdviseLcSink(NULL);
  return S_OK;
}

#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/vco50SqlHandle.cpp <==
/*!***************************************************************************

  module      : vco50SqlHandle.cpp

  -------------------------------------------------------------------------

  responsible : FerdiF

  special area: C++ SQL Class   
  description : Implementation of SqlHandle 
				
  
  last changed: 2000-03-08  11:22
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

#ifndef GCO50SQLHANDLE_H
#include "gco50SqlHandle.h"
#endif
#ifndef GCO501SQL_H
#include "gco501SQL.h"
#endif
#ifndef GCO51CSQLSESSIONCONTEXT_H
#include "gco51CSqlSessionContext.h"
#endif
#include "hsp81.h"

#if !defined (EXT_CLIENT_SQL)
#if defined(QUICK) || defined(SLOW)
externC teo00_Longint
sqlk_rangeviolation (               // ALLIN
                     teo00_Longint     val,
                     teo00_Longint     minVal,
                     teo00_Longint     maxVal,
                     int               lineno,
                     const char       *fileName)
{ int x=0; x=1/10*x; return -1; };

/*----------------------------------------*/

externC void
sqlk_assert (                      // ALLIN
             int            kind,
             int            lineno,
             const char    *filename,
             const char    *condition)
{ int x=0; x=x/10*0; };

#endif
#endif

/*----------------------------------------------------------------------*/
/* Implementation of default error handler                              */
/*----------------------------------------------------------------------*/

void
#if defined(WIN32)
__cdecl
#endif
sqlDefaultHandler ( SqlHandle* p_sqlhandle )
{
  if ( p_sqlhandle->sqlCode() != 100 ) {
    if ( p_sqlhandle->sqlIsUnicodeErrMsg() )
      throw DbpError(DbpError::DB_ERROR_UNICODE,
      p_sqlhandle->sqlCode(),
      p_sqlhandle->sqlUnicodeErrorMsg());
    else
      throw DbpError(DbpError::DB_ERROR,
      p_sqlhandle->sqlCode(),
      p_sqlhandle->sqlErrorMsg());
  }
}

/*----------------------------------------------------------------------*/
/* Implementation of class SqlHandle                                    */
/*----------------------------------------------------------------------*/

SqlHandle::SqlHandle () {
  m_session         = NULL;
  m_session_context = NULL;
  /* PTS 1120804 */
# if !defined (EXT_CLIENT_SQL)
    co10_GetLcSink()->GetSqlSessionContext(REINTERPRET_CAST(void**,&m_session_context));
    if (m_session_context == NULL) {
      m_session_context = new co51CSqlSessionContext(*this);
      co10_GetLcSink()->SetSqlSessionContext((void*)m_session_context);
      sqlSetHandler(&sqlDefaultHandler);
    }
    m_session_context->incRefCnt();
# else
    m_session_context = new co51CSqlSessionContext(*this);
    sqlSetHandler(&sqlDefaultHandler);
# endif
};

/*----------------------------------------------------------------------*/

SqlHandle::~SqlHandle () {
  m_session_context->deleteSelf();
};

/*----- PTS 1120804 ----------------------------------------------------*/

typedef void (__cdecl * sqlHandler ) ( SqlHandle* p_sqlhandle );
sqlHandler SqlHandle::sqlSetHandler(sqlHandler p) {
  sqlHandler p_old = m_session_context->getHandler();
  m_session_context->setHandler(p);
  return (p_old);
};

/*----- PTS 1120804 ----------------------------------------------------*/

void SqlHandle::sqlSetDefaultHandler() {
  sqlSetHandler(&sqlDefaultHandler);
};

/*----------------------------------------------------------------------*/

SQL SqlHandle::sql(const char* stmt) {
  return SQL(this, stmt);
};

/*----------------------------------------------------------------------*/

SQL SqlHandle::sql(const DbpTypeUnicode* stmt) {
  return SQL(this, stmt);
};

/*----------------------------------------------------------------------*/

short SqlHandle::sqlCode () const {
  if (m_session_context)
    return m_session_context->sqlCode ();
  else 
    return e_unknown_error;
};

/*----------------------------------------------------------------------*/

const char* SqlHandle::sqlErrorMsg() const {
  if (m_session_context) 
    return m_session_context->sqlErrorMsg ();
  else
    return NULL;
};

/*----------------------------------------------------------------------*/

const DbpTypeUnicode* SqlHandle::sqlUnicodeErrorMsg() const {
  if (m_session_context) 
    return m_session_context->sqlUnicodeErrorMsg ();
  else
    return NULL;
};

/*----------------------------------------------------------------------*/
#if !defined (EXT_CLIENT_SQL)
void SqlHandle::sqlExceptionHandler(DbpError& e) {
  if ( *m_session )
  switch (e.m_errorKind) {
  case DbpError::DB_ERROR :
  case DbpError::RTE_ERROR :
  case DbpError::USER_DEFINED :
    {
      sqlRaiseError ((short) e.m_errorNo, &e.m_errorText[0]);
      break;
    }
  case DbpError::DB_ERROR_UNICODE :
  case DbpError::USER_DEFINED_UNICODE :
    {
      sqlRaiseError ((short) e.m_errorNo, REINTERPRET_CAST(DbpTypeUnicode*,&e.m_errorText[0]));
      break;
    }
  case DbpError::HRESULT_ERROR :
    {
      (*m_session)->HResultError (e.m_errorNo);
      break;
    }
  default :
    dbpOpError ("Invalid DbpError, kind = %d, errno = %d", e.m_errorKind, e.m_errorNo);
    throw;
  }
}
#endif

/*----------------------------------------------------------------------*/

long SqlHandle::sqlErrorPos () const {
  if (m_session_context) 
    return m_session_context->sqlErrorPos ();
  else 
    return -1;
}

/*----------------------------------------------------------------------*/

void  SqlHandle::sqlInitSession (IUnknown** s) {
  m_session = (IliveCacheSink**) s;
};

/*----------------------------------------------------------------------*/

int  SqlHandle::sqlIsUnicodeErrMsg () const {
  return m_session_context->sqlIsUnicodeErrMsg();
};

/*----------------------------------------------------------------------*/

long SqlHandle::sqlResultCount () const {
  if (m_session_context) 
    return m_session_context->sqlResultCount ();
  else
    return -1;
}

/*----------------------------------------------------------------------*/

void SqlHandle::sqlRaiseError (short msgno, const char* errmsg) {
#if defined(EXT_CLIENT_SQL)
  throw DbpError(msgno,errmsg);
#else
  if ( *m_session )
    (*m_session)->SetError (msgno, (tsp00_Int4)strlen (errmsg), (unsigned char*) errmsg,
    csp_ascii );
#endif
};

/*----------------------------------------------------------------------*/

void SqlHandle::sqlRaiseError (short msgno, const DbpTypeUnicode* errmsg) {
#if defined(EXT_CLIENT_SQL)
  throw DbpError(msgno,errmsg);
#else
  if ( *m_session ) {
    tsp81_UCS2Char    UCS2Blank;
    int               UCS2Swap;
    UCS2Blank.s = 32;
    UCS2Swap    =  (UCS2Blank.c[0] ? 1 : 0 ); 
    
    int len = sp81UCS2strlen((tsp81_UCS2Char*)errmsg);
    
    if ( UCS2Swap ) {
      DbpTypeUnicode    l_errmsg[256];

      if ( len > 256 ) len = 256;
      sp81UCS2strncpy( REINTERPRET_CAST(tsp81_UCS2Char*,l_errmsg), 
        REINTERPRET_CAST(const tsp81_UCS2Char*,errmsg), 256 );
      for ( int i=0; i<len; i++) {
        l_errmsg[i] = l_errmsg[i] << 8;
      }
      (*m_session)->SetError (msgno, len*2, (unsigned char*) &l_errmsg[0], csp_unicode);
    }
    else
      (*m_session)->SetError (msgno, len*2, (unsigned char*) errmsg, csp_unicode);
  }
#endif
};

/*----------------------------------------------------------------------*/

void SqlHandle::sqlResetSession( ) {
//  m_sqlmsg->m_snd_packet_size = 0;
};

/*----------------------------------------------------------------------*/

void SqlHandle::sqlSetMode(const SqlOpt::SqlSessionMode mode) {
  if (m_session_context) 
    m_session_context->sqlSetMode(mode);
}

/*----------------------------------------------------------------------*/

const char* SqlHandle::sqlState () const {
  if (m_session_context)
    return m_session_context->sqlState();
  else
    return NULL;
};

/*----------------------------------------------------------------------*/

char SqlHandle::sqlWarning (int i) const {
  if (m_session_context)
    return m_session_context->sqlWarning(i);
  else
    return ' ';
};

/*----------------------------------------------------------------------*/

#if !defined (EXT_CLIENT_SQL)

HRESULT SqlHandle::AdviseSqlSession () {
  if ( m_session )
    dbpAdviseLcSink(*m_session);
  return S_OK;
}

/*----------------------------------------------------------------------*/

HRESULT SqlHandle::UnAdviseSqlSession () {
  dbpAdviseLcSink(NULL);
  m_session_context->setSink(NULL); /* PTS 1121948 */
  return S_OK;
}

/*----- PTS 1120804 ----------------------------------------------------*/

void SqlHandle::sqlSetMethodCallEpilog() {
  if (m_session_context) {
    m_session_context->setMethodCallEpilog();
  }
}

/*----- PTS 1120804 ----------------------------------------------------*/

void SqlHandle::sqlResetMethodCallEpilog() {
  if (m_session_context) {
    m_session_context->resetMethodCallEpilog();  
  }
}

/*----- PTS 1120804 ----------------------------------------------------*/

void SqlHandle::sqlSetCurrMethod(unsigned char* name) {
  if(m_session_context) {
    m_session_context->setCurrMethod(name);
  }
}

/*----- PTS 1120804 ----------------------------------------------------*/

void SqlHandle::sqlResetCurrMethod() {
  if (m_session_context) {
    m_session_context->resetCurrMethod();
  }
}

/*----- PTS 1120804 ----------------------------------------------------*/

bool SqlHandle::sqlGetMethodCallMonitorInfo (SqlMonitorData& info) const {
  if (m_session_context) {
    return m_session_context->getMethodCallMonitorInfo(info);
  }
  else {
    return false;
  }
}

/*----- PTS 1120804 -----------------------------------------------------*/

void SqlHandle::sqlResetMonitor() {
  if (m_session_context) {
    m_session_context->getMonitor()->Reset();
  }
}

/*----- PTS 1120804 -----------------------------------------------------*/

void SqlHandle::sqlSetRuntime(unsigned int Runtime) {
  if (m_session_context) {
    m_session_context->getMonitor()->SetRuntime(Runtime);
  }
}

#endif
